@@ -6,9 +6,19 @@ from pathlib import Path
 
 from pyvalem.formula import Formula, FormulaParseError
 
-from .exceptions import LineValueError, LineCommentError, LineWarning, DefParseError
-from .utils import DataClass
-from .utils import get_file_raw_text_over_api, parse_exomol_line
+from .exceptions import (
+    LineValueError,
+    LineCommentError,
+    LineWarning,
+    DefParseError,
+    DefConsistencyError,
+)
+from .utils import (
+    get_file_raw_text_over_api,
+    parse_exomol_line,
+    get_num_columns,
+    DataClass,
+)
 
 
 # noinspection PyUnresolvedReferences
@@ -179,6 +189,8 @@ class DefParser:
         isotopologue_slug=None,
         dataset_name=None,
     ):
+        self.local = path is not None
+        self.path = Path(path) if path is not None else None
         self.raw_text = None
         self.file_name = None
         self._save_raw_text(path, molecule_slug, isotopologue_slug, dataset_name)
@@ -207,6 +219,7 @@ class DefParser:
         self.num_trans_files = None
         self.max_wavenumber = None
         self.high_energy_complete = None
+        self.parsed = False
 
     def _save_raw_text(self, path, molecule_slug, isotopologue_slug, dataset_name):
         """Save the raw text of a *.def* file as an instance attribute
@@ -236,7 +249,7 @@ class DefParser:
                 self.raw_text = fp.read()
             self.file_name = Path(path).name
 
-    def parse(self, warn_on_comments):
+    def parse(self, warn_on_comments=True):
         """Parse the *.def* file text from the `raw_text` attribute.
 
         Populates all the instance attributes incrementally, util it hits the end of
@@ -426,6 +439,50 @@ class DefParser:
             # file one day!
         except (LineValueError, LineCommentError) as e:
             raise DefParseError(str(e))
+        self.parsed = True
+
+    def check_consistency(self):
+        """A method checking the consistency between the .def file and
+        the .states file.
+
+        Only checks if the .states file and .trans files exist in the
+        expected path, and if the .states file has the expected number
+        of columns based on the .def file.
+        Will call the `parse` method, if not parsed yet.
+
+        Raises
+        ------
+        DefParseError
+            If `parse` not called yet before and the file could not be
+            parsed.
+        DefConsistencyError
+            If the .states or .trans files do not exist where they
+            should, or if the .states file has an unexpected number of
+            columns.
+        """
+        assert self.local, "check_consistency only available in the local mode!"
+        if not self.parsed:
+            self.parse(warn_on_comments=False)
+        file_name = self.path.name[:-4]
+        dataset_dir = self.path.parent
+        for states_suffix in ["states", "states.bz2"]:
+            # some .states files are not bz2-compressed!
+            states_path = dataset_dir / f"{file_name}.{states_suffix}"
+            if states_path.is_file():
+                break
+        else:
+            raise DefConsistencyError(
+                f"A '{file_name}.states(.bz2)' file needs to exist in {dataset_dir}!"
+            )
+        num_columns = get_num_columns(states_path)
+        if num_columns != len(self.get_states_header()):
+            raise DefConsistencyError(
+                f"The number of columns in {states_path.name} ({num_columns}) does not "
+                f"agree with the length of the expected .states header parsed from the "
+                f"{self.path.name} file ({len(self.get_states_header())})."
+            )
+        if not list(dataset_dir.glob(f"{file_name}*.trans.bz2")):
+            raise DefConsistencyError(f"No trans files found in {dataset_dir}!")
 
     def get_quanta_labels(self):
         """Quanta labels for all the quanta extracted from the parsed *.def* file.
@@ -456,3 +513,60 @@ class DefParser:
             states_header.append("g_J")
         states_header.extend(self.get_quanta_labels())
         return states_header
+
+
+def parse_def(isotopologue_slug, dataset_name=None, data_dir_path="."):
+    """A top-level function for getting and parsing the exomol .def file
+    belonging to a single dataset.
+
+    In the best case, this can be called from within the exomol data
+    directory on the ExoMol server, only with the isotopologue slug
+    as the single argument.
+
+    Parameters
+    ----------
+    isotopologue_slug : str
+        Isotopologue slug of the dataset the .def file of which should
+        be parsed and returned.
+    dataset_name : str, optional
+        Only needed if more than a single dataset exists for the given
+        isotopologue.
+    data_dir_path : Path or str, optional
+        Path to the exomol data directory, containing all the
+        directories belonging to all the individual molecules.
+        Does not need to be passed if called from within the directory.
+
+    Returns
+    -------
+    DefParser
+        Parsed instance of the DefParser class.
+
+    Raises
+    ------
+    DefParseError
+        If the .def file could not be found or if more than a single
+        dataset exists for the given isotopologue slug.
+        See the DefParser.parse
+    """
+    data_dir_path = Path(data_dir_path)
+    if dataset_name is None:
+        dataset_name = "*"
+    wildcard = (
+        f"*/{isotopologue_slug}/{dataset_name}/{isotopologue_slug}_{dataset_name}.def"
+    )
+    def_files_available = sorted(data_dir_path.glob(wildcard))
+    if not def_files_available:
+        raise DefParseError(
+            f"No .def file for the {data_dir_path / wildcard} wildcard could be found!"
+        )
+    if len(def_files_available) > 1:
+        paths_available = "\n".join("  " + str(path) for path in def_files_available)
+        raise DefParseError(
+            f"Multiple .def files found:\n"
+            f"{paths_available}\n"
+            f"Please pass the dataset_name argument."
+        )
+    def_file_path = def_files_available[0]
+    def_parser = DefParser(path=def_file_path)
+    def_parser.parse()
+    return def_parser
